@@ -13,8 +13,8 @@ Defines fields, which contain the actual data stored on a discrete grid.
 Inheritance structure of the classes:
 
 
-.. inheritance-diagram:: pde.fields.base pde.fields.scalar pde.fields.vectorial
-        pde.fields.tensorial pde.fields.collection
+.. inheritance-diagram:: scalar.ScalarField vectorial.VectorField tensorial.Tensor2Field
+        collection.FieldCollection
    :parts: 1
 
 The details of the classes are explained below:
