@@ -12,6 +12,7 @@ from typing import List  # @UnusedImport
 from typing import TYPE_CHECKING, Callable, Dict, Optional, Sequence, Union
 
 import numpy as np
+from numpy.typing import DTypeLike
 
 from ..grids import CartesianGrid, UnitGrid
 from ..grids.base import DomainError, GridBase
@@ -32,7 +33,12 @@ class ScalarField(DataFieldBase):
     @classmethod
     @fill_in_docstring
     def from_expression(
-        cls, grid: GridBase, expression: str, *, label: str = None, dtype=None
+        cls,
+        grid: GridBase,
+        expression: str,
+        *,
+        label: str = None,
+        dtype: DTypeLike = None,
     ) -> ScalarField:
         """create a scalar field on a grid from a given expression
 
@@ -68,9 +74,7 @@ class ScalarField(DataFieldBase):
             for cells in np.ndindex(*grid.shape):
                 data[cells] = expr(grid.cell_coords[cells])
 
-        return cls(  # lgtm [py/call-to-non-callable]
-            grid=grid, data=data, label=label, dtype=dtype
-        )
+        return cls(grid=grid, data=data, label=label, dtype=dtype)
 
     @classmethod
     def from_image(
@@ -276,7 +280,7 @@ class ScalarField(DataFieldBase):
         ax_retain = tuple(sorted(set(ax_all) - set(ax_remove)))
 
         # determine the new grid
-        subgrid = self.grid.get_subgrid(ax_retain)
+        sliced_grid = self.grid.slice(ax_retain)
 
         # calculate the new data
         if method == "integral":
@@ -291,7 +295,7 @@ class ScalarField(DataFieldBase):
             raise ValueError(f"Unknown projection method `{method}`")
 
         # create the new field instance
-        return self.__class__(grid=subgrid, data=subdata, label=label)
+        return self.__class__(grid=sliced_grid, data=subdata, label=label)
 
     def slice(
         self, position: Dict[str, float], *, method: str = "nearest", label: str = None
@@ -348,7 +352,7 @@ class ScalarField(DataFieldBase):
         # determine the axes left after slicing and the new grid
         ax_all = range(grid.num_axes)
         ax_retain = tuple(sorted(set(ax_all) - set(ax_remove)))
-        subgrid = grid.get_subgrid(ax_retain)
+        sliced_grid = grid.slice(ax_retain)
 
         # obtain the sliced data
         if method == "nearest":
@@ -371,7 +375,7 @@ class ScalarField(DataFieldBase):
             raise ValueError(f"Unknown slicing method `{method}`")
 
         # create the new field instance
-        return self.__class__(grid=subgrid, data=subdata, label=label)
+        return self.__class__(grid=sliced_grid, data=subdata, label=label)
 
     def to_scalar(
         self, scalar: Union[str, Callable] = "auto", *, label: Optional[str] = None
