@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING, Callable, List, Optional, Sequence, Tuple, Uni
 
 import numba as nb
 import numpy as np
+from numpy.typing import DTypeLike
 
 from ..grids.base import DimensionError, GridBase
 from ..tools.docstrings import fill_in_docstring
@@ -38,7 +39,7 @@ class Tensor2Field(DataFieldBase):
         expressions: Sequence[Sequence[str]],
         *,
         label: str = None,
-        dtype=None,
+        dtype: DTypeLike = None,
     ) -> Tensor2Field:
         """create a tensor field on a grid from given expressions
 
@@ -78,9 +79,7 @@ class Tensor2Field(DataFieldBase):
         points = {name: grid.cell_coords[..., i] for i, name in enumerate(grid.axes)}
 
         # evaluate all vector components at all points
-        data: List[List[Optional[np.ndarray]]] = [
-            [None] * grid.dim for _ in range(grid.dim)
-        ]
+        data: List[List[np.ndarray]] = [[None] * grid.dim for _ in range(grid.dim)]  # type: ignore
         for i in range(grid.dim):
             for j in range(grid.dim):
                 expr = ScalarExpression(expressions[i][j], signature=grid.axes)
@@ -88,9 +87,7 @@ class Tensor2Field(DataFieldBase):
                 data[i][j] = values
 
         # create vector field from the data
-        return cls(  # lgtm [py/call-to-non-callable]
-            grid=grid, data=data, label=label, dtype=dtype
-        )
+        return cls(grid=grid, data=data, label=label, dtype=dtype)
 
     def _get_axes_index(
         self, key: Tuple[Union[int, str], Union[int, str]]
@@ -104,15 +101,19 @@ class Tensor2Field(DataFieldBase):
         return tuple(self.grid.get_axis_index(k) for k in key)  # type: ignore
 
     def __getitem__(self, key: Tuple[Union[int, str], Union[int, str]]) -> ScalarField:
-        """extract a component of the VectorField"""
-        return ScalarField(self.grid, self.data[self._get_axes_index(key)])
+        """extract a single component of the tensor field as a scalar field"""
+        return ScalarField(
+            self.grid,
+            data=self._data_full[self._get_axes_index(key)],
+            with_ghost_cells=True,
+        )
 
     def __setitem__(
         self,
         key: Tuple[Union[int, str], Union[int, str]],
         value: Union[NumberOrArray, ScalarField],
     ):
-        """set a component of the VectorField"""
+        """set a single component of the tensor field"""
         idx = self._get_axes_index(key)
         if isinstance(value, ScalarField):
             self.grid.assert_grid_compatible(value.grid)
@@ -345,9 +346,7 @@ class Tensor2Field(DataFieldBase):
             label (str, optional):
                 Name of the returned field
             **kwargs:
-                Additional arguments affecting how the operator behaves. For instance,
-                the argument `normal_bcs` can be used to control whether boundary
-                conditions only specify normal components or not.
+                Additional arguments affecting how the operator behaves.
 
         Returns:
             :class:`~pde.fields.vectorial.VectorField`: result of applying the operator
@@ -357,7 +356,7 @@ class Tensor2Field(DataFieldBase):
     @property
     def integral(self) -> np.ndarray:
         """:class:`~numpy.ndarray`: integral of each component over space"""
-        return self.grid.integrate(self.data)
+        return self.grid.integrate(self.data)  # type: ignore
 
     def transpose(self, label: str = "transpose") -> Tensor2Field:
         """return the transpose of the tensor field
