@@ -12,7 +12,7 @@ import inspect
 import itertools
 import json
 import logging
-import warnings
+import math
 from abc import ABCMeta, abstractmethod
 from typing import (
     TYPE_CHECKING,
@@ -246,6 +246,11 @@ class GridBase(metaclass=ABCMeta):
         """tuple of int: the number of support points of each axis"""
         return self._shape
 
+    @property
+    def num_cells(self) -> int:
+        """int: the number of cells in this grid"""
+        return math.prod(self.shape)
+
     @property
     def _shape_full(self) -> Tuple[int, ...]:
         """tuple of int: number of support points including ghost points"""
@@ -665,47 +670,6 @@ class GridBase(metaclass=ABCMeta):
             raise ValueError(f"Unknown source coordinates `{source}`")
         raise ValueError(f"Unknown target coordinates `{target}`")
 
-    def cell_to_point(self, cells: np.ndarray, cartesian: bool = True) -> np.ndarray:
-        """convert cell coordinates to real coordinates
-
-        Args:
-            cells (:class:`~numpy.ndarray`):
-                Indices of the cells whose center coordinates are requested.
-                This can be float values to indicate positions relative to the
-                cell center.
-            cartesian (bool):
-                Determines whether the point is returned in Cartesian
-                coordinates or grid coordinates.
-
-        Returns:
-            :class:`~numpy.ndarray`: The center points of the respective cells
-
-        Warning:
-            This method is deprecated since 2022-03-14 and will be removed soon.
-        """
-        # deprecated since 2022-03-14
-        warnings.warn("`cell_to_point` is deprecated. Use `transform` method instead")
-        if cartesian:
-            return self.transform(cells, "cell", "cartesian")
-        else:
-            return self.transform(cells, "cell", "grid")
-
-    def point_to_cell(self, points: np.ndarray) -> np.ndarray:
-        """Determine cell(s) corresponding to given point(s)
-
-        Args:
-            points (:class:`~numpy.ndarray`): Real coordinates
-
-        Returns:
-            :class:`~numpy.ndarray`: The indices of the respective cells
-
-        Warning:
-            This method is deprecated since 2022-03-14 and will be removed soon.
-        """
-        # deprecated since 2022-03-14
-        warnings.warn("`point_to_cell` is deprecated. Use `transform` method instead")
-        return self.transform(points, "cartesian", "cell")
-
     @abstractmethod
     def polar_coordinates_real(
         self, origin: np.ndarray, *, ret_angle: bool = False
@@ -1163,7 +1127,7 @@ class GridBase(metaclass=ABCMeta):
         """
         if all(np.isscalar(d) for d in self.cell_volume_data):
             # all cells have the same volume
-            cell_volume = np.product(self.cell_volume_data)  # type: ignore
+            cell_volume = np.prod(self.cell_volume_data)  # type: ignore
 
             @jit
             def get_cell_volume(*args) -> float:
@@ -1259,6 +1223,7 @@ class GridBase(metaclass=ABCMeta):
 
         return get_axis_data  # type: ignore
 
+    @cached_method()
     def _make_interpolator_compiled(
         self, *, fill: Number = None, full_data: bool = False, cell_coords: bool = False
     ) -> Callable[[np.ndarray, np.ndarray], np.ndarray]:
@@ -1278,11 +1243,10 @@ class GridBase(metaclass=ABCMeta):
                 point coordinates.
 
         Returns:
-            A function which returns interpolated values when called with
-            arbitrary positions within the space of the grid. The signature of
-            this function is (data, point), where `data` is the numpy array
-            containing the field data and position is denotes the position in
-            grid coordinates.
+            A function which returns interpolated values when called with arbitrary
+            positions within the space of the grid. The signature of this function is
+            (data, point), where `data` is the numpy array containing the field data and
+            position denotes the position in grid coordinates.
         """
         if full_data and fill is not None:
             self._logger.warning("Interpolation of full data does not use `fill`.")
