@@ -28,6 +28,7 @@ from hashlib import sha1
 from typing import Callable, Dict, Iterable, Optional, TypeVar
 
 import numpy as np
+from scipy import sparse
 
 TFunc = TypeVar("TFunc", bound="Callable")
 
@@ -61,6 +62,9 @@ def objects_equal(a, b) -> bool:
             return False
         return all(objects_equal(x, y) for x, y in zip(a, b))
 
+    if isinstance(a, sparse.csr_matrix) and isinstance(b, sparse.csr_matrix):
+        return a.shape == b.shape and (a != b).nnz == 0  # type: ignore
+
     # use direct comparison
     return a == b  # type: ignore
 
