@@ -8,16 +8,20 @@ Handles configuration variables of the package
    get_package_versions
    parse_version_str
    check_package_version
+   packages_from_requirements
    environment
    
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
 import collections
+import contextlib
 import importlib
+import re
 import sys
 import warnings
-from typing import Any, Dict, List
+from pathlib import Path
+from typing import Any, Dict, List, Union
 
 from .misc import module_available
 from .parameters import Parameter
@@ -39,17 +43,17 @@ DEFAULT_CONFIG: List[Parameter] = [
         "the precision of the mathematical calculations.",
     ),
     Parameter(
-        "numba.parallel",
+        "numba.multithreading",
         True,
         bool,
-        "Determines whether multiple cores are used in numba-compiled code.",
+        "Determines whether multiple threads are used in numba-compiled code.",
     ),
     Parameter(
-        "numba.parallel_threshold",
+        "numba.multithreading_threshold",
         256**2,
         int,
-        "Minimal number of support points before multithreading or multiprocessing is "
-        "enabled in the numba compilations.",
+        "Minimal number of support points before multithreading is enabled in numba "
+        "compilations.",
     ),
 ]
 
@@ -79,8 +83,30 @@ class Config(collections.UserDict):
             self.update(items)
         self.mode = mode
 
+    def _translate_deprecated_key(self, key: str) -> str:
+        """helper function that allows using deprecated config items"""
+        # the depreciations have been introduced on 2022-09-04 and are scheduled to be
+        # removed after 2023-03-04
+        if key == "numba.parallel":
+            warnings.warn(
+                "Option `numba.parallel` has been renamed to `numba.multithreading`",
+                DeprecationWarning,
+            )
+            return "numba.multithreading"
+
+        elif key == "numba.parallel_threshold":
+            warnings.warn(
+                "Option `numba.parallel_threshold` has been renamed to "
+                "`numba.multithreading_threshold`",
+                DeprecationWarning,
+            )
+            return "numba.multithreading_threshold"
+
+        return key
+
     def __getitem__(self, key: str):
         """retrieve item `key`"""
+        key = self._translate_deprecated_key(key)
         parameter = self.data[key]
         if isinstance(parameter, Parameter):
             return parameter.convert()
@@ -89,6 +115,7 @@ class Config(collections.UserDict):
 
     def __setitem__(self, key: str, value):
         """update item `key` with `value`"""
+        key = self._translate_deprecated_key(key)
         if self.mode == "insert":
             self.data[key] = value
 
@@ -109,6 +136,7 @@ class Config(collections.UserDict):
 
     def __delitem__(self, key: str):
         """removes item `key`"""
+        key = self._translate_deprecated_key(key)
         if self.mode == "insert":
             del self.data[key]
         else:
@@ -126,6 +154,23 @@ class Config(collections.UserDict):
         """represent the configuration as a string"""
         return f"{self.__class__.__name__}({repr(self.to_dict())})"
 
+    @contextlib.contextmanager
+    def __call__(self, values: Dict[str, Any] = None, **kwargs):
+        """context manager temporarily changing the configuration
+
+        Args:
+            values (dict): New configuration parameters
+            **kwargs: New configuration parameters
+        """
+        data_initial = self.data.copy()  # save old configuration
+        # set new configuration
+        if values is not None:
+            self.data.update(values)
+        self.data.update(kwargs)
+        yield  # return to caller
+        # restore old configuration
+        self.data = data_initial
+
 
 def get_package_versions(
     packages: List[str], *, na_str="not available"
@@ -142,7 +187,7 @@ def get_package_versions(
     versions: Dict[str, str] = {}
     for name in sorted(packages):
         try:
-            module = importlib.import_module(name)
+            module = importlib.import_module(name.replace("-", "_"))
         except ImportError:
             versions[name] = na_str
         else:
@@ -178,6 +223,28 @@ def check_package_version(package_name: str, min_version: str):
             warnings.warn(f"{msg} (installed: {version})")
 
 
+def packages_from_requirements(requirements_file: Union[Path, str]) -> List[str]:
+    """read package names from a requirements file
+
+    Args:
+        requirements_file (str or :class:`~pathlib.Path`):
+            The file from which everything is read
+
+    Returns:
+        list of package names
+    """
+    result = []
+    with open(requirements_file) as fp:
+        for line in fp:
+            line_s = line.strip()
+            if line_s.startswith("#"):
+                continue
+            res = re.search(r"[a-zA-Z0-9_\-]+", line_s)
+            if res:
+                result.append(res.group(0))
+    return result
+
+
 def environment() -> Dict[str, Any]:
     """obtain information about the compute environment
 
@@ -188,9 +255,12 @@ def environment() -> Dict[str, Any]:
 
     from .. import __version__ as package_version
     from .. import config
+    from . import mpi
     from .numba import numba_environment
     from .plotting import get_plotting_context
 
+    PACKAGE_PATH = Path(__file__).resolve().parents[2]
+
     result: Dict[str, Any] = {}
     result["package version"] = package_version
     result["python version"] = sys.version
@@ -200,19 +270,26 @@ def environment() -> Dict[str, Any]:
     result["config"] = config.to_dict()
 
     # add details for mandatory packages
-    result["mandatory packages"] = get_package_versions(
-        ["matplotlib", "numba", "numpy", "scipy", "sympy"]
-    )
+    packages_min = packages_from_requirements(PACKAGE_PATH / "requirements.txt")
+    result["mandatory packages"] = get_package_versions(packages_min)
     result["matplotlib environment"] = {
         "backend": mpl.get_backend(),
         "plotting context": get_plotting_context().__class__.__name__,
     }
 
     # add details about optional packages
-    result["optional packages"] = get_package_versions(
-        ["h5py", "napari", "pandas", "pyfftw", "tqdm"]
-    )
+    tests_folder = PACKAGE_PATH / "tests"
+    packages = set(packages_from_requirements(tests_folder / "requirements_full.txt"))
+    packages |= set(packages_from_requirements(tests_folder / "requirements_mpi.txt"))
+    packages -= set(packages_min)
+    result["optional packages"] = get_package_versions(sorted(packages))
     if module_available("numba"):
         result["numba environment"] = numba_environment()
 
+    # add information about MPI environment
+    if mpi.size > 1:
+        result["multiprocessing"] = {"initialized": True, "size": mpi.size}
+    else:
+        result["multiprocessing"] = {"initialized": False}
+
     return result
