@@ -67,7 +67,9 @@ class Parameter:
             converted_value = cls(default_value)
             if isinstance(converted_value, np.ndarray):
                 # numpy arrays are checked for each individual value
-                valid_default = np.allclose(converted_value, default_value)
+                valid_default = np.allclose(
+                    converted_value, default_value, equal_nan=True
+                )
 
             else:
                 # other values are compared directly. Note that we also check identity
