@@ -4,15 +4,15 @@ Provides support for mypy type checking of the package
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
-from typing import Any, Callable, Sequence, Tuple, Union
+from typing import Callable, Tuple, Union
 
 import numpy as np
+from numpy.typing import ArrayLike  # @UnusedImport
 
 Real = Union[int, float]
 Number = Union[Real, complex]
 NumberOrArray = Union[Number, np.ndarray]
 FloatNumerical = Union[float, np.ndarray]
-ArrayLike = Union[NumberOrArray, Sequence[NumberOrArray], Sequence[Sequence[Any]]]
 
 
 try:
@@ -20,6 +20,8 @@ try:
 
 except ImportError:
     # Protocol is not defined (likely because python version <= 3.7
+    # We demand python version 3.8 since 2022-08-23
+    # This fallback can thus be removed after 2022-02-23
     OperatorType = Callable[[np.ndarray, np.ndarray], None]
     AdjacentEvaluator = Callable[[np.ndarray, int, Tuple[int, ...]], float]
     CellVolume = Callable[..., float]
